@@ -347,11 +347,14 @@ class Comparison (Condition):
         field = self.entity._sql_field(self.column, aliases=aliases)
         if aggregate:
             field = 'SUM(%s)' % field
-        paramed = '%s %s %s' % (field, self.operator, '%s')
         if isinstance(self.value, tuple) or isinstance(self.value, list):
-            paramed = paramed % 'ANY (%s)'
-            self.value = list(self.value)  # Coerce tuples to pg ARRAYs...
-        return cursor.mogrify(paramed, (self.value,))
+            assert self.operator == '=', \
+                'Disjunctions must use "=" for column "%s"' % field
+            vals = [cursor.mogrify('%s', (v,)) for v in self.value]
+            return '%s IN (%s)' % (field, ', '.join(vals))
+        else:
+            paramed = '%s %s %s' % (field, self.operator, '%s')
+            return cursor.mogrify(paramed, (self.value,))
 
 
 def QueryOR(db):
@@ -1061,10 +1064,10 @@ class Sorter (object):
         elif isinstance(e, tuple):
             assert len(e) == 2, 'invalid sort expression'
             return (self.default_entity, e[0], self._normalize_order(e[1]))
-            # elif len(e) == 3: 
-                # assert e[0] in _ENTITIES, 'invalid entity: %s' % e[0] 
-                # self.entities.add(_ENTITIES[e[0]]) 
-                # return (_ENTITIES[e[0]], e[1], self._normalize_order(e[2])) 
+            # elif len(e) == 3:
+                # assert e[0] in _ENTITIES, 'invalid entity: %s' % e[0]
+                # self.entities.add(_ENTITIES[e[0]])
+                # return (_ENTITIES[e[0]], e[1], self._normalize_order(e[2]))
         else:
             raise ValueError(
                 "Sortby expressions must be strings "
