@@ -71,33 +71,63 @@ class Entity (object):
         return cols
 
     @classmethod
-    def _sql_fields(cls):
+    def sql_fields(cls):
         """
-        Just like `nfldb.Entity._sql_columns`, except derived fields
-        are also returned.
+        Returns a list of all SQL fields across all tables for this
+        entity, including derived fields. This method can be used
+        in conjunction with `nfldb.Entity.from_row_tuple` to quickly
+        create new `nfldb` objects without every constructing a dict.
         """
-        return cls._sql_columns() + cls._sql_tables['derived']
+        if not hasattr(cls, '_cached_sql_fields'):
+            cls._cached_sql_fields = cls._sql_columns()
+            cls._cached_sql_fields += cls._sql_tables['derived']
+        return cls._cached_sql_fields
 
     @classmethod
-    def _sql_select_from(cls, fields=None, aliases=None):
+    def from_row_dict(cls, db, row):
         """
-        Return a valid SQL SELECT string for the given table type. If
-        `prefix` is not `None`, then it will be used as a prefix for each
-        SQL field.
-
-        This function includes derived fields in `tabtype`.
-
-        This should only be used if you're writing SQL queries by hand.
+        Introduces a new entity object from a full SQL row result from
+        the entity's tables. (i.e., `row` is a dictionary mapping
+        column to value.) Note that the column names must be of the
+        form '{entity_name}_{column_name}'. For example, in the `game`
+        table, the `gsis_id` column must be named `game_gsis_id` in
+        `row`.
         """
-        if fields is None:
-            fields = cls._sql_fields()
+        obj = cls(db)
+        seta = setattr
+        prefix = cls._sql_primary_table() + '_'
+        slice_from = len(prefix)
+        for k in row:
+            if k.startswith(prefix):
+                seta(obj, k[slice_from:], row[k])
+        return obj
 
+    @classmethod
+    def from_row_tuple(cls, db, t):
+        """
+        Given a tuple `t` corresponding to a result from a SELECT query,
+        this will construct a new instance for this entity. Note that
+        the tuple `t` must be in *exact* correspondence with the columns
+        returned by `nfldb.Entity.sql_fields`.
+        """
+        cols = cls.sql_fields()
+        seta = setattr
+        obj = cls(db)
+        for i, field in enumerate(cols):
+            seta(obj, field, t[i])
+        return obj
+
+    @classmethod
+    def _sql_from(cls, aliases=None):
+        """
+        Return a valid SQL `FROM table AS alias [LEFT JOIN extra_table
+        ...]` string for this entity.
+        """
         # This is a little hokey. Pick the first table as the 'FROM' table.
         # Subsequent tables are joined.
         from_table = cls._sql_primary_table()
         as_from_table = cls._sql_table_alias(from_table, aliases)
 
-        columns = cls._sql_select_fields(fields, aliases=aliases)
         extra_tables = ''
         for table, _ in cls._sql_tables['tables'][1:]:
             extra_tables += cls._sql_join_to(cls,
@@ -106,11 +136,9 @@ class Entity (object):
                                              from_aliases=aliases,
                                              to_aliases=aliases)
         return '''
-            SELECT {columns}
             FROM {from_table} AS {as_from_table}
             {extra_tables}
-        '''.format(columns=', '.join(columns),
-                   from_table=from_table, as_from_table=as_from_table,
+        '''.format(from_table=from_table, as_from_table=as_from_table,
                    extra_tables=extra_tables)
 
     @classmethod
@@ -130,7 +158,8 @@ class Entity (object):
         if wrap is None:
             wrap = lambda x: x
         sql = lambda f: wrap(cls._sql_field(f, aliases=aliases))
-        return ['%s AS %s' % (sql(f), f) for f in fields]
+        entity_prefix = cls._sql_primary_table()
+        return ['%s AS %s_%s' % (sql(f), entity_prefix, f) for f in fields]
 
     @classmethod
     def _sql_relation_distance(cls_from, cls_to):
@@ -208,7 +237,7 @@ class Entity (object):
         """
         Given a **sub class** `cls_to` of `nfldb.Entity`, produce
         as many SQL `LEFT JOIN` clauses as is necessary so that all
-        fields in `cls_to._sql_fields()` are available for filtering.
+        fields in `cls_to.sql_fields()` are available for filtering.
 
         See the documentation for `nfldb.Entity._sql_join_to` for
         information on the parameters.
